@@ -5,6 +5,6 @@ TAR=../libxml-security-java_$VERSION.orig.tar.xz
 DIR=libxml-security-java-$VERSION
 TAG="xmlsec-$VERSION"
 
-svn export http://svn.apache.org/repos/asf/santuario/xml-security-java/tags/${TAG}/ $DIR
+svn export https://svn.apache.org/repos/asf/santuario/xml-security-java/tags/${TAG}/ $DIR
 tar -c -J -f $TAR --exclude '*.jar' --exclude 'rfc*.txt' $DIR
 rm -rf $DIR ../$TAG
